/*
* Copyright © 2010 Martin Gräßlin <kde@martin-graesslin.com>
* Copyright © 2008 Dennis Kasprzyk <onestone@opencompositing.org>
* Copyright © 2006 Novell, Inc.
* Copyright © 2006 Volker Krause <vkrause@kde.org>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
* MA 02110-1301, USA.
*
* Author: David Reveman <davidr@novell.com>
*/
#ifndef AURORAE_CLIENT_H
#define AURORAE_CLIENT_H
#include "aurorae.h"
#include <QtGui/QGraphicsView>

namespace Aurorae
{

class AuroraeScene;

class Client : public QGraphicsView
{
    Q_OBJECT
public:
    Client(AuroraeTheme *theme, WId parentId, WId clientId, WId frameId, const QRect &geometry = QRect());

    void updateName();
    void updateState();
    void updateIcons();
    void updateWindowGeometry();
    void handleActiveChange(bool active);
    void updateFrame(WId id);
    WId frameId() const;
    WId windowId() const;

private Q_SLOTS:
    void closeWindow();
    void menuClicked();
    void minimizeWindow();
    void maximize(Qt::MouseButtons buttons);
    void titleDoubleClicked();
    void toggleKeepAbove();
    void toggleKeepBelow();
    void toggleOnAllDesktops();
    void toggleShade();

private:
    void init();
    void resizeDecoration(bool force = false);
    void createDecoration();
    void updateProperty();
    AuroraeTheme *m_theme;
    AuroraeScene *m_scene;
    WId m_parentId;
    WId m_clientId;
    WId m_frameId;
    QRect m_geometry;
    unsigned long m_state;
};

}

#endif // AURORAE_CLIENT_H
